==> dnet-openaireplus-mapping-utils-6.3.30-sources.jar: eu/dnetlib/data/bulktag/Constraints.java <==
package eu.dnetlib.data.bulktag;

import com.google.gson.Gson;
import eu.dnetlib.data.bulktag.selectioncriteria.VerbResolver;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;


import java.io.Serializable;
import java.lang.reflect.InvocationTargetException;
import java.util.List;
import java.util.Map;

/**
 * Created by miriam on 02/08/2018.
 */
public class Constraints implements Serializable {
    private static final Log log = LogFactory.getLog(Constraints.class);
    private ConstraintEncapsulator ce;
    //private List<Constraint> ce;


    public Constraints() {
    }

    public ConstraintEncapsulator getCe() {
        return ce;
    }

    public void setCe(ConstraintEncapsulator ce) {
        this.ce = ce;
    }

    public void setSc(String json){

        ce = new Gson().fromJson(json, ConstraintEncapsulator.class);

    }

    void setSelection(VerbResolver resolver) {
        for(Constraint st: ce.getConstraint()){

            try {
                st.setSelection(resolver);
            } catch (NoSuchMethodException e) {
                log.error(e.getMessage());
            } catch (IllegalAccessException e) {
                log.error(e.getMessage());
            } catch (InvocationTargetException e) {
                log.error(e.getMessage());
            } catch (InstantiationException e) {
                log.error(e.getMessage());
            }
        }

    }

//    //Constraint in and
//    public boolean verifyCriteria(Map<String,String> param){
//        for(Constraint ce: ce){
//            if(!ce.verifyCriteria(param.get(ce.getField())))
//                return false;
//        }
//        return true;
//    }

    //Constraint in and
    public boolean verifyCriteria(Map<String,List<String>> param) throws NullPointerException {
        for(Constraint sc: ce.getConstraint()){
            boolean verified = false;
            for(String value : param.get(sc.getField())){
                try {
                    if (sc.verifyCriteria(value.trim())) {
                        verified = true;
                    }
                }catch(NullPointerException npe){
                    log.info(new Gson().toJson(this));
                    throw new NullPointerException();

                }
            }
            if(!verified)
                return verified;
        }
        return true;
    }
}

==> dnet-openaireplus-mapping-utils-6.3.31-sources.jar: eu/dnetlib/data/bulktag/Constraints.java <==
package eu.dnetlib.data.bulktag;

import com.google.common.reflect.TypeToken;
import com.google.gson.Gson;
import eu.dnetlib.data.bulktag.selectioncriteria.VerbResolver;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;


import java.io.Serializable;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Type;
import java.util.Collection;
import java.util.List;
import java.util.Map;

/**
 * Created by miriam on 02/08/2018.
 */
public class Constraints implements Serializable {
    private static final Log log = LogFactory.getLog(Constraints.class);
    //private ConstraintEncapsulator ce;
    private List<Constraint> constraint;


    public Constraints() {
    }
    public List<Constraint> getConstraint() {
        return constraint;
    }

    public void setConstraint(List<Constraint> constraint) {
        this.constraint = constraint;
    }

    public void setSc(String json){
        Type collectionType = new TypeToken<Collection<Constraint>>(){}.getType();
        constraint = new Gson().fromJson(json, collectionType);

    }

    void setSelection(VerbResolver resolver) {
        for(Constraint st: constraint){

            try {
                st.setSelection(resolver);
            } catch (NoSuchMethodException e) {
                log.error(e.getMessage());
            } catch (IllegalAccessException e) {
                log.error(e.getMessage());
            } catch (InvocationTargetException e) {
                log.error(e.getMessage());
            } catch (InstantiationException e) {
                log.error(e.getMessage());
            }
        }

    }

//    //Constraint in and
//    public boolean verifyCriteria(Map<String,String> param){
//        for(Constraint constraint: constraint){
//            if(!constraint.verifyCriteria(param.get(constraint.getField())))
//                return false;
//        }
//        return true;
//    }

    //Constraint in and
    public boolean verifyCriteria(Map<String,List<String>> param){

        for(Constraint sc: constraint){
            boolean verified = false;
            for(String value : param.get(sc.getField())){
                if (sc.verifyCriteria(value.trim())){
                    verified = true;
                }
            }
            if(!verified)
                return verified;
        }
        return true;
    }
  /*  public ConstraintEncapsulator getCe() {
        return ce;
    }

    public void setCe(ConstraintEncapsulator ce) {
        this.ce = ce;
    }

    public void setConstraint(String json){

        ce = new Gson().fromJson(json, ConstraintEncapsulator.class);

    }

    void setSelection(VerbResolver resolver) {
        for(Constraint st: ce.getConstraint()){

            try {
                st.setSelection(resolver);
            } catch (NoSuchMethodException e) {
                log.error(e.getMessage());
            } catch (IllegalAccessException e) {
                log.error(e.getMessage());
            } catch (InvocationTargetException e) {
                log.error(e.getMessage());
            } catch (InstantiationException e) {
                log.error(e.getMessage());
            }
        }

    }

//    //Constraint in and
//    public boolean verifyCriteria(Map<String,String> param){
//        for(Constraint ce: ce){
//            if(!ce.verifyCriteria(param.get(ce.getField())))
//                return false;
//        }
//        return true;
//    }

    //Constraint in and
    public boolean verifyCriteria(Map<String,List<String>> param) throws NullPointerException {
        for(Constraint constraint: ce.getConstraint()){
            boolean verified = false;
            for(String value : param.get(constraint.getField())){
                try {
                    if (constraint.verifyCriteria(value.trim())) {
                        verified = true;
                    }
                }catch(NullPointerException npe){
                    log.info(new Gson().toJson(this));
                    throw new NullPointerException();

                }
            }
            if(!verified)
                return verified;
        }
        return true;
    }*/
}
